Stan Math Library: stan/math/prim/scal/fun/corr_constrain.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
corr_constrain.hpp File Reference
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::corr_constrain (const T x)
| Return the result of transforming the specified scalar to have a valid correlation value between -1 and 1 (inclusive). More...
template<typename T >
T | stan::math::corr_constrain (const T x, T &lp)
| Return the result of transforming the specified scalar to have a valid correlation value between -1 and 1 (inclusive). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.